# CoreX messaging - sqs

This package provides an implementation of the CoreX messaging interface for sqs.

## Installation
~~~bash
pip install corex-messaging-sqs
~~~

## Usage
~~~python
from corex_messaging_sqs.handler import SqsHandler
handler = SqsHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
